@@ -40,7 +40,7 @@
 #'   created.
 #' @param replace.strl \emph{logical.} If \code{TRUE}, replace the reference to
 #'  a strL string in the data.frame with the actual value. The strl attribute
-#'  will be removed from the data.frame.
+#'  will be removed from the data.frame (see details).
 #' @param convert.dates \emph{logical.} If \code{TRUE}, Stata dates are
 #'  converted.
 #' @param add.rownames \emph{logical.} If \code{TRUE}, the first column will be
@@ -67,8 +67,8 @@
 #' Stata 13 introduced a new character type called strL. strLs are able to store
 #'  strings up to 2 billion characters.  While R is able to store
 #'  strings of this size in a character vector, the printed representation of such 
-#'  vectors looks rather cluttered, so by default only a reference is saved in the 
-#'  data.frame (\code{replace.strl=FALSE}). 
+#'  vectors looks rather cluttered, so it's possible to save only a reference in the 
+#'  data.frame with option \code{replace.strl=FALSE}. 
 #'
 #' In R, you may use rownames to store characters (see for instance
 #'  \code{data(swiss)}). In Stata, this is not possible and rownames have to be
@@ -113,7 +113,7 @@
 read.dta13 <- function(file, convert.factors = TRUE, generate.factors=FALSE,
                        encoding = localeToCharset()[1], fromEncoding=NULL,
                        convert.underscore = FALSE, missing.type = FALSE,
-                       convert.dates = TRUE, replace.strl = FALSE,
+                       convert.dates = TRUE, replace.strl = TRUE,
                        add.rownames = FALSE, nonint.factors=FALSE) {
   # Check if path is a url
   if (length(grep("^(http|ftp|https)://", file))) {
@@ -256,23 +256,19 @@ read.dta13 <- function(file, convert.factors = TRUE, generate.factors=FALSE,
         attr(data, "strl") <- strl
       }
     }
-}
+  }
 
   var.labels <- attr(data, "var.labels")
 
-  if (replace.strl) {
-    if (version >= 117L) {
-      strl <- c("")
-      names(strl) <- "00000000000000000000"
-      strl <- c(strl, attr(data,"strl"))
-      for (j in seq(ncol(data))[types == 32768] ) {
-        data[, j] <- strl[data[,j]]
-      }
-      # if strls are in data.frame remove attribute strl
-      attr(data, "strl") <- NULL
-    } else {
-      message("replace.strl is only available for dta-format >= 117.")
+  if (replace.strl & version >= 117L) {
+    strl <- c("")
+    names(strl) <- "00000000000000000000"
+    strl <- c(strl, attr(data,"strl"))
+    for (j in seq(ncol(data))[types == 32768] ) {
+      data[, j] <- strl[data[,j]]
     }
+    # if strls are in data.frame remove attribute strl
+    attr(data, "strl") <- NULL
   }
 
 
